@@ -25,7 +25,7 @@ from plib.stdlib.localize import (
     monthname, monthname_long)
 
 
-__version__ = "0.9.4"
+__version__ = "0.9.5"
 
 
 blogfile_exts = ["json"]
@@ -885,6 +885,10 @@ class Blog(BlogObject):
             self.page_class(self, source, format)
             for source, format in self.sources
         ]
+    
+    @extendable_property()
+    def render_items(self):
+        return [(page.encoded, page.filepath) for page in self.pages]
 
 
 # INITIALIZATION
