@@ -2,7 +2,7 @@
 """
 Module EXT -- Simple Blog Extension Loader
 Package SIMPLEBLOG
-Copyright (C) 2012 by Peter A. Donis
+Copyright (C) 2012-2013 by Peter A. Donis
 
 Released under the GNU General Public License, Version 2
 See the LICENSE and README files for more information
@@ -21,8 +21,10 @@ def load(config, extensions):
     # This hack is useful for extensions that need to access the
     # config in module or class level code, e.g., in decorators
     BlogExtension.config = config
-    exts = load_subs(extensions,
+    exts = load_subs(
+        extensions,
         "extension", config.get('extension_dir', ""),
-        BlogExtensionError, BlogExtension)
+        BlogExtensionError, BlogExtension
+    )
     for mod, klass in exts:
         mod.extension = klass(config)
